@@ -28,7 +28,13 @@ search_stn_name <- function(search_term, hydat_path = NULL) {
   results <- realtime_stations() |>
     dplyr::bind_rows(suppressMessages(hy_stations(hydat_path = hydat_con))) |>
     dplyr::distinct(STATION_NUMBER, .keep_all = TRUE) |>
-    dplyr::select(STATION_NUMBER, STATION_NAME, PROV_TERR_STATE_LOC, LATITUDE, LONGITUDE)
+    dplyr::select(
+      STATION_NUMBER,
+      STATION_NAME,
+      PROV_TERR_STATE_LOC,
+      LATITUDE,
+      LONGITUDE
+    )
 
   results <- results[grepl(toupper(search_term), results$STATION_NAME), ]
 
@@ -54,7 +60,13 @@ search_stn_number <- function(search_term, hydat_path = NULL) {
   results <- realtime_stations() |>
     dplyr::bind_rows(suppressMessages(hy_stations(hydat_path = hydat_con))) |>
     dplyr::distinct(STATION_NUMBER, .keep_all = TRUE) |>
-    dplyr::select(STATION_NUMBER, STATION_NAME, PROV_TERR_STATE_LOC, LATITUDE, LONGITUDE)
+    dplyr::select(
+      STATION_NUMBER,
+      STATION_NAME,
+      PROV_TERR_STATE_LOC,
+      LATITUDE,
+      LONGITUDE
+    )
 
   results <- results[grepl(toupper(search_term), results$STATION_NUMBER), ]
 
